@@ -1,4 +1,4 @@
-# $Id: ControlTower.pm 41360 2014-04-17 14:44:59Z anton $
+# $Id: ControlTower.pm 42388 2014-10-17 07:58:12Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/ControlTower.pm $
 use strict;
 package UvT::PwdModifier::ControlTower;
@@ -88,7 +88,7 @@ sub regulateTraffic {
 	my $passwordExpirationStage = $userinfo->{passwordExpirationStage} // '';
 	my $accountStatus = $userinfo->{accountStatus} // '';
 	my $accountBlocked = $userinfo->{accountBlocked};
-	my $accountTemporaryDisabled = $userinfo->{accountTemporaryDisabled};
+	my $accountTemporarilyDisabled = $userinfo->{accountTemporarilyDisabled};
 	my $unpaidFees = $userinfo->{unpaidFees};
 	my $uid = $userinfo->{uid};
 
@@ -108,7 +108,7 @@ sub regulateTraffic {
 	  $accountStatus =~ /disabled|exit/i && do { $implicitPasswordStatus = 'closed'; last switch};
 	  $accountBlocked && do { $implicitPasswordStatus = 'closed'; last switch};
 	  $unpaidFees && do { $implicitPasswordStatus = 'closed'; last switch};
-	  $accountTemporaryDisabled && do { $implicitPasswordStatus = 'hijacked'; last switch};
+	  $accountTemporarilyDisabled && do { $implicitPasswordStatus = 'hijacked'; last switch};
 	  $passwordExpirationStage && do { $implicitPasswordStatus = $self->passwordStatusFromExpiration(); last switch};
 	  $implicitPasswordStatus = 'normal';
 	}
@@ -123,7 +123,6 @@ sub regulateTraffic {
 		$passwordStatus = $implicitPasswordStatus;
 	}
 	
-
 	unless($self->readonly) { 
 		unless ($passwordStatus) {
 			# No passwordStatus in ldap yet: write it now.
@@ -143,6 +142,10 @@ sub regulateTraffic {
 	my @denied = ();
 	
   statusSwitch: {
+
+	  last statusSwitch
+				  if $command eq 'getadinfo';
+
 	  $passwordStatus =~ /^closed/i 
 		  && do {
 			  last statusSwitch if $command =~ /qamstatus/i and $admin;
@@ -153,27 +156,27 @@ sub regulateTraffic {
 			  }
 
 			  if ($accountBlocked and $command !~ /unblockAccount|getTblock/i) {  
-				  push(@denied, "Account Blocked at: $accountBlocked");
-				  push(@denied, 'contactHelpdesk') unless $admin;
+				  push(@denied, "\$accountBlocked_txt at: $accountBlocked.");
+				  push(@denied, '$contactHelpdesk_txt') unless $admin;
 				  last statusSwitch;
 			  }
 
 			  if ($accountStatus =~ /^disabled|^exit/i ) {
 				  push(@denied, "accountStatus $accountStatus");
-				  push(@denied, 'contactHelpdesk') unless $admin;
+				  push(@denied, '$contactHelpdesk_txt') unless $admin;
 				  last statusSwitch;
 			  } 
 
 			  if ($unpaidFees){
-				  push(@denied, "UnpaidFees $unpaidFees");
-				  push(@denied, 'contactStudentDesk');
+				  push(@denied, "\$unpaidFees_txt. $unpaidFees");
+				  push(@denied, '$contactStudentDesk_txt');
 			  }
 			  last statusSwitch;
 	  };
 
 	  $passwordStatus =~ /set-only/i 
 		  && do {
-			  push(@denied, 'contactStudentDesk') if $command =~ /setQAM/i;
+			  push(@denied, '$contactStudentDesk_txt') if $command =~ /setQAM/i;
 			  # laat verder alles doorgaan
 			  last statusSwitch;
 	  };
@@ -181,7 +184,7 @@ sub regulateTraffic {
 	  $passwordStatus =~ /admin\-required/i 
 		  && do { 
 			  last statusSwitch if $command =~ /qamstatus/i;
-			  push(@denied, 'adminRequired') unless $admin;
+			  push(@denied, '$adminRequired_txt') unless $admin;
 			  last statusSwitch;
 	  };
 
@@ -193,7 +196,7 @@ sub regulateTraffic {
 
 	  $passwordStatus =~ /^hijacked/i 
 		  && do {
-			  my $date = $accountTemporaryDisabled;
+			  my $date = $accountTemporarilyDisabled;
 
 			  last statusSwitch  
 				  if ( $command =~ /^unsetTmpPwd|^getTsetpwd|^getTblock|^blockAccount|^disablePassword|qamstatus/i 
@@ -201,8 +204,8 @@ sub regulateTraffic {
 					   $admin
 				  );
 
-			  push(@denied, "Account temporary disabled at: $date");
-			  push(@denied, 'adminRequired') unless $admin;
+			  push(@denied, "Account temporarily disabled at: $date.");
+			  push(@denied, '$adminRequired_txt') unless $admin;
 			  last statusSwitch;
 
 	  };
@@ -210,12 +213,11 @@ sub regulateTraffic {
 
 	if (@denied) {
 #		my $reasons = join(' ', @denied);
-		$self->{fields}->{details} = "RegulateTrafficReport: Command: \"$command\" denied for account: \"$uid\"";
+		
+		my $adminAccount = $admin || 'NO ADMIN';
+		$self->{fields}->{details} = "RegulateTrafficReport: Command: \"$command\" denied for account: \"$uid\", admin: $adminAccount";
 		my @messages;
-		push (@messages, 'requestDenied');
-		push (@messages, @denied);
-		$self->{fields}->{message} = [@messages];
-
+		$self->{fields}->{message} = '${requestDenied_txt}. ' . join(' ', @denied);
 		$self->{fields}->{error} = "requestDenied" unless $self->{fields}->{error};
 	} else {
 		warn "RegulateTraficReport: Command: $command on $uid is allowed." if $self->debug;
