@@ -1,4 +1,4 @@
-# $Id: Directory.pm 42176 2014-09-09 09:51:55Z anton $
+# $Id: Directory.pm 42397 2014-10-17 14:14:41Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -23,7 +23,7 @@ sub orgstats {
 
 	my $cf = $self->cf;
 	my @config = $cf->value('ldap_orgstat');
-	die $cf->error if $cf->error;
+	die $cf->error if $cf && $cf->error;
 
 	my $attr = shift @config;
 	foreach my $status ($self->ldapEntry->get_value($attr)) {
@@ -68,8 +68,8 @@ sub tiasPrivateEmail {
 	return $self->ldapEntry->get_value('tiasPrivateEmail');
 }
 
-sub accountTemporaryDisabled {
-	return $self->ldapEntry->get_value('accountTemporaryDisabled');
+sub accountTemporarilyDisabled {
+	return $self->ldapEntry->get_value('accountTemporarilyDisabled');
 }
 
 
@@ -82,7 +82,7 @@ sub stuff {
         accountBlocked
         accountStatus
         accountSuspended
-        accountTemporaryDisabled
+        accountTemporarilyDisabled
         cn
         datePasswdChanged
         employeeNumber
@@ -106,7 +106,6 @@ sub stuff {
         tiasPrivateEmail
         uid            
         unpaidFees
-
          )) {
 		$userinfo{$attr} = $entry->get_value($attr);
 	}
@@ -160,6 +159,7 @@ field 'ssl' => 1;
 
 sub ldapError {
 	#callback heeft geen $self
+	warn "ldapError";
 	my $res = $self;
 	# code 4 is sizelimit exceeded
 	confess $res->error unless $res->code == 4;
@@ -233,16 +233,29 @@ sub ldap_connection {
 	return $ldap;
 }
 
+
+sub ldapSimpleSearch {
+	 my ($filter) = @_;
+	 my $ldap = $self->ldap_connection();
+	 my $cf = $self->cf;
+	 my $base = $self->ldapbase;
+	 die $cf->error if $cf && $cf->error;
+	 warn "ldapSimpleSearch: filter: $filter, base: $base" if $self->debug;
+	 my $msg = eval {
+		  $ldap->search(base => $base, filter => $filter);
+	 };
+	 my $err = $@;
+	 if ($err) {
+		 warn "ldapSimpleSearch Error: ,", Dumper($err);
+	 }
+	 return $msg;
+}
+
 sub ldap_search_filter {
 	my ($filter) = @_;
-	my $ldap = $self->ldap_connection();
-	my $cf = $self->cf;
-	my $base = $self->ldapbase;
-	die $cf->error if $cf->error;
-	warn "filter: $filter, base: $base" if $self->debug;
 
-	my $search = $ldap->search(base => $base, filter => $filter);
-	my @entries = $search->entries;
+	my $msg = $self->ldapSimpleSearch(@_);
+	my @entries = $msg->entries;
 
 	return undef, "no match found for filter: '$filter'"
 		unless @entries;
@@ -275,10 +288,15 @@ sub ldap_search_anr {
 
 
 sub verify_password {
-	my ($victim, $password, $trySHA) = @_;
+	my ($filter, $password, $trySHA) = @_;
 	my $ldap = $self->ldap_connection();
+	my $debug = $self->debug;
 
-	my ($entry, $err) = $self->ldap_search_uid($victim);
+	if ($filter !~ /\=/) {
+		$filter = "uid=$filter";
+	}
+
+	my ($entry, $err) = $self->ldap_search_filter($filter);
 	return $err unless ($entry);
 
 	my $dn = $entry->dn;
@@ -286,6 +304,8 @@ sub verify_password {
 	$err = $@;
 	# fixme, verander dit in 'getFallbackPassword'
 
+	warn "Error: $err" if $err;
+
 	if ($err and $trySHA) {
 		my $ctx = Digest::SHA->new;
 		$ctx->add($password.$trySHA);
@@ -293,7 +313,7 @@ sub verify_password {
 		my $converted = MIME::Base64::encode_base64($digest);
 		# vergeet niet de \n eraf te slopen!
 		chomp $converted;
-		warn "converted: $converted";
+		warn "converted: $converted" if $debug;
 		eval { $ldap->bind($dn, password => $converted) };
 		$err = $@;
 	}
@@ -349,8 +369,8 @@ sub getUIDsByFilter {
 }
 
 
-sub listTemporaryDisabled {
-	my $filter = '(AccountTemporaryDisabled=*)';
+sub listTemporarilyDisabled {
+	my $filter = '(AccountTemporarilyDisabled=*)';
 	return $self->getUIDsByFilter($filter);
 }
 
@@ -396,7 +416,7 @@ sub getEntriesByUID {
 	my $ldap = $self->ldap_connection();
 	my $cf = $self->cf;
 	my $base = $self->ldapbase;
-	die $cf->error if $cf->error;
+	die $cf->error if $cf && $cf->error;
 
 	my $filter = bless(
 			{equalityMatch => {attributeDesc => 'uid', assertionValue => $uid}},
